==> jc-1.4.0.tar.gz: java/lang/reflect/Proxy.h <==
// public class java.lang.reflect.Proxy

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 918947cfca55c534 java_lang_reflect_Proxy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy_H_
#define _JC_java_lang_reflect_Proxy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_InvocationHandler$object;
struct _jc_java_lang_reflect_Proxy__24ProxyData$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy$sub_refs	_jc_java_lang_reflect_Proxy$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy$sub_nonrefs	_jc_java_lang_reflect_Proxy$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy$refs	_jc_java_lang_reflect_Proxy$refs;
typedef struct _jc_java_lang_reflect_Proxy$nonrefs	_jc_java_lang_reflect_Proxy$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy$object	_jc_java_lang_reflect_Proxy$object;

typedef struct _jc_java_lang_reflect_Proxy$fields_struct	_jc_java_lang_reflect_Proxy$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy$vmethods	_jc_java_lang_reflect_Proxy$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy$vtable	_jc_java_lang_reflect_Proxy$vtable;
typedef const struct _jc_java_lang_reflect_Proxy$vtype	_jc_java_lang_reflect_Proxy$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24InvocationHandler;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24Proxy;
	struct _jc_object	*proxyClasses;
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_Proxy$fields_struct _jc_java_lang_reflect_Proxy$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy$method$_init$064c9c67d938b315(_jc_env *, struct _jc_java_lang_reflect_Proxy$object *, struct _jc_object *);

// Static methods
extern void _jc_java_lang_reflect_Proxy$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$generateProxyClass0$a85643e346bb07a7(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *);
extern struct _jc_object *_jc_java_lang_reflect_Proxy$method$getInvocationHandler$14ce4ef7bd7daa3a(_jc_env *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$getProxyClass$457bce4339dabd76(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$getProxyClass0$16e88895abc4b04e(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *);
extern struct _jc_java_lang_reflect_Proxy__24ProxyData$object *_jc_java_lang_reflect_Proxy$method$getProxyData0$eb70448f92410286(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *);
extern jboolean _jc_java_lang_reflect_Proxy$method$isProxyClass$60d1cb46b4e0664a(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_Object$object *_jc_java_lang_reflect_Proxy$method$newProxyInstance$b5569f99fc305178(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_Proxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy$vmethods	java_lang_reflect_Proxy;
};

// Vtype
struct _jc_java_lang_reflect_Proxy$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy$sub_refs {
	struct _jc_object	*h;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy$refs {
    _jc_java_lang_reflect_Proxy$sub_refs	java_lang_reflect_Proxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy$sub_nonrefs	java_lang_reflect_Proxy;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy$object {
	_jc_java_lang_reflect_Proxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy$vtype	*vtype;
	_jc_java_lang_reflect_Proxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy$vtype _jc_java_lang_reflect_Proxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy$class_object;

#endif	/* _JC_java_lang_reflect_Proxy_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/Proxy.h <==
// public class java.lang.reflect.Proxy

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 918947cfca55c534 java_lang_reflect_Proxy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy_H_
#define _JC_java_lang_reflect_Proxy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_InvocationHandler$object;
struct _jc_java_lang_reflect_Proxy__24ProxyData$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy$sub_refs	_jc_java_lang_reflect_Proxy$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy$sub_nonrefs	_jc_java_lang_reflect_Proxy$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy$refs	_jc_java_lang_reflect_Proxy$refs;
typedef struct _jc_java_lang_reflect_Proxy$nonrefs	_jc_java_lang_reflect_Proxy$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy$object	_jc_java_lang_reflect_Proxy$object;

typedef struct _jc_java_lang_reflect_Proxy$fields_struct	_jc_java_lang_reflect_Proxy$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy$vmethods	_jc_java_lang_reflect_Proxy$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy$vtable	_jc_java_lang_reflect_Proxy$vtable;
typedef const struct _jc_java_lang_reflect_Proxy$vtype	_jc_java_lang_reflect_Proxy$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24InvocationHandler;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24reflect__24Proxy;
	struct _jc_object	*proxyClasses;
	jlong	serialVersionUID;
};
extern _jc_java_lang_reflect_Proxy$fields_struct _jc_java_lang_reflect_Proxy$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy$method$_init$064c9c67d938b315(_jc_env *, struct _jc_java_lang_reflect_Proxy$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_reflect_Proxy$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$generateProxyClass0$a85643e346bb07a7(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_reflect_Proxy__24ProxyData$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_lang_reflect_Proxy$method$getInvocationHandler$14ce4ef7bd7daa3a(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$getProxyClass$457bce4339dabd76(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy$method$getProxyClass0$16e88895abc4b04e(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_reflect_Proxy__24ProxyData$object *_jc_java_lang_reflect_Proxy$method$getProxyData0$eb70448f92410286(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Proxy$method$isProxyClass$60d1cb46b4e0664a(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_lang_reflect_Proxy$method$newProxyInstance$b5569f99fc305178(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_Proxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy$vmethods	java_lang_reflect_Proxy;
};

// Vtype
struct _jc_java_lang_reflect_Proxy$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy$sub_refs {
	struct _jc_object	*h;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy$refs {
    _jc_java_lang_reflect_Proxy$sub_refs	java_lang_reflect_Proxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy$sub_nonrefs	java_lang_reflect_Proxy;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy$object {
	_jc_java_lang_reflect_Proxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy$vtype	*vtype;
	_jc_java_lang_reflect_Proxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy$vtype _jc_java_lang_reflect_Proxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy$class_object;

#endif	/* _JC_java_lang_reflect_Proxy_H_ */
